# $Id: module.mk.in,v 1.22 2002/12/10 05:46:11 stefan Exp $
#
# This source file is a part of the Fresco Project.
# Copyright (C) 1999, 2000 Stefan Seefeld <stefan@fresco.org> 
# http://www.fresco.org
#
# This library is free software; you can redistribute it and/or
# modify it under the terms of the GNU Library General Public
# License as published by the Free Software Foundation; either
# version 2 of the License, or (at your option) any later version.
#
# This library is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# Library General Public License for more details.
#
# You should have received a copy of the GNU Library General Public
# License along with this library; if not, write to the
# Free Software Foundation, Inc., 675 Mass Ave, Cambridge,
# MA 02139, USA.

# this file defines common rules to build Berlin plugins.
# It requires the following variables to be set within the
# including Makefile:
#
# builddir      the build tree root
#
# SRC:   	the list of all source files to be compiled and linked
#        	into the module
# TARGET:	the name of the module to be generated
#
# CPPFLAGS:	preprocessor flags
# CXXFLAGS:	compiler flags
# LDFLAGS:	linker flags
# LIBS:		libraries to be linked to the module
#
#

docdir	:= $(top_builddir)/share/doc/Berlin

# Compilation and linking flags.
CXXFLAGS+= $(SO_CXXFLAGS)
LDFLAGS += $(SO_LDFLAGS)
LIBS	:= -L$(top_builddir)/lib -lBerlin $(EXTRA_LIBS)
CPPFLAGS+= $(EXTRA_CPPFLAGS)

.FORCE:

.PHONY: all install uninstall clean distclean maintainer-clean

DEP	:= $(patsubst %.cc, %.d, $(SRC))
OBJ	:= $(patsubst %.cc, %.o, $(SRC))
HDR	?= $(patsubst $(srcdir)/%, %, $(wildcard $(srcdir)/*.hh))
HSYN	:= $(patsubst %, %.syn, $(HDR))
SSYN	:= $(patsubst %, %.syn, $(SRC))
XREF	:= $(patsubst %, %.xref, $(HDR) $(SRC))

TARGET	:= $(MODULE).so
MANUAL	:= $(abs_top_builddir)/share/doc/Berlin/$(docdir)/html

vpath %.hh  $(srcdir)
vpath %.cc  $(srcdir)

all:	$(TARGET)

$(TARGET):	$(DEP) $(OBJ)
		@echo linking $(@F)
		$(CXX) $(LDFLAGS) $(SO_LDFLAGS) -o $@ $(OBJ) $(LIBS)

depend: $(DEP)

xref:	Kit.xref Kit.syn

doc:	$(MANUAL)

$(MODULE).xref:	$(XREF)
	@echo linking xref files together
	@mkdir -p $(docdir)/sxr/modules
	@compile-xref -o $@ $^

$(MODULE).syn:	$(SSYN) $(HSYN)
	@echo linking synopsis files together
	@mkdir -p $(docdir)/sxr/modules
	@$(SYNOPSIS) -o $@ $^

$(MANUAL):	$(HSYN)
	@echo formatting $(@F)
	@$(SYNOPSIS) -c $(cdir)/synopsis.py -Wc,formatter=KitHTML -o $@ $(HSYN)
	@touch $@

install:	all
	$(SHTOOL) mkdir -f -p -m 755 $(DESTDIR)$(libdir)/Berlin
	$(SHTOOL) install -C -m 755 $(TARGET) $(DESTDIR)$(libdir)/Berlin

install-doc: doc
	$(SHTOOL) mkdir -f -p -m 755 $(DESTDIR)$(datadir)/doc/Berlin/$(docdir)
	cp -r $(abs_top_builddir)/share/doc/Berlin/$(docdir)/html $(DESTDIR)$(datadir)/doc/Berlin/$(docdir)

clean:	
	rm -f $(TARGET)
	rm -f *.o *.d

distclean:	clean
	rm -f Makefile

maintainer-clean: distclean

%.d:	%.cc %.hh
	@echo generating dependencies for $(<F)
	$(SHELL) -ec '$(CXX) $(DEPFLAGS) -I$(top_builddir)/include $(CPPFLAGS) $< | sed "s/$*\\.o[ :]*/$*\\.d $*\\.o : /g" > $@'

%.o:	%.cc
	@echo compiling $(@F)
	$(CXX) -I$(top_builddir)/include $(CPPFLAGS) $(CXXFLAGS) $(SO_CXXFLAGS) -c $< -o $@

%.hh.syn %.hh.xref:	%.hh
	@echo parsing $(^F)
	$(SYNOPSIS) -c $(cdir)/synopsis.py -Wc,parser=Fresco,linker=Fresco -I$(top_builddir)/include $(patsubst -I%, -I%, $(CPPFLAGS)) -Wp,-x,$(<F).xref -o $*.hh.syn $?

%.cc.syn %.cc.xref:	%.cc
	@echo parsing $(^F)
	$(SYNOPSIS) -c $(cdir)/synopsis.py -Wc,parser=Fresco,linker=Fresco -I$(top_builddir)/include $(patsubst -I%, -I%, $(CPPFLAGS)) -Wp,-x,$(<F).xref -o $*.cc.syn $?

ifneq (,$(findstring depend, $(MAKECMDGOALS)))
$(DEP): %.d:	.FORCE
endif

ifeq (,$(filter $(MAKECMDGOALS), depend clean distclean maintainer-clean))
-include $(DEP)
endif
